summaryrefslogtreecommitdiffstats
path: root/src/RankManager.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/RankManager.h')
-rw-r--r--src/RankManager.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/RankManager.h b/src/RankManager.h
index abe860b1c..e2600dde0 100644
--- a/src/RankManager.h
+++ b/src/RankManager.h
@@ -53,7 +53,7 @@ public:
~cRankManager();
/** Initializes the rank manager. Performs migration and default-setting if no data is found in the DB.
- The a_MojangAPI param is used when migrating from old ini files, to look up player UUIDs. */
+ The a_MojangAPI param is used to keep player names in sync with UUIDs, since Mojang allows username changes. */
void Initialize(cMojangAPI & a_MojangAPI);
/** Returns the name of the rank that the specified player has assigned to them.
@@ -273,7 +273,7 @@ protected:
/** Set to true once the manager is initialized. */
bool m_IsInitialized;
/** The MojangAPI instance that is used for translating playernames to UUIDs.
Set in Initialize(), may be nullptr. */
cMojangAPI * m_MojangAPI;
@@ -273,7 +273,7 @@ protected:
/** Set to true once the manager is initialized. */
bool m_IsInitialized;
- /** The MojangAPI instance that is used for translating playernames to UUIDs.
+ /** The MojangAPI instance that is used for keeping player names and UUIDs in sync.
Set in Initialize(), may be nullptr. */
cMojangAPI * m_MojangAPI;